Examples
===================

Getting Started Examples
-------------------------
- `Getting Started With OpenAlex <https://github.com/SciSciCollective/pyscisci/blob/master/examples/Getting_Started/Getting%20Started%20with%20OpenAlex.ipynb>`_
- `Getting Started With MAG <https://github.com/SciSciCollective/pyscisci/blob/master/examples/Getting_Started/Getting%20Started%20with%20MAG.ipynb>`_
- `Getting Started With WoS <https://github.com/SciSciCollective/pyscisci/blob/master/examples/Getting_Started/Getting%20Started%20with%20WOS.ipynb>`_
- `Getting Started With DBLP <https://github.com/SciSciCollective/pyscisci/blob/master/examples/Getting_Started/Getting%20Started%20with%20DBLP.ipynb>`_
- `Getting Started With APS <https://github.com/SciSciCollective/pyscisci/blob/master/examples/Getting_Started/Getting%20Started%20with%20APS.ipynb>`_
- `Getting Started With PubMed <https://github.com/SciSciCollective/pyscisci/blob/master/examples/Getting_Started/Getting%20Started%20with%20PubMed.ipynb>`_
- `Getting Started With Custom DB <https://github.com/SciSciCollective/pyscisci/blob/master/examples/Getting_Started/Getting%20Started%20with%20a%20Custom%20DB.ipynb>`_
- `The Growth of Science <https://github.com/SciSciCollective/pyscisci/blob/master/examples/Getting_Started/The%20Growth%20of%20Science.ipynb>`_

Method Examples
-------------------------
- `The Diffusion of Scientific Credit <https://github.com/SciSciCollective/pyscisci/blob/master/examples/Method_Examples/Example%20of%20Diffusion%20of%20Scientific%20Credit.ipynb>`_
- `Credit Allocation <https://github.com/SciSciCollective/pyscisci/blob/master/examples/Method_Examples/Example%20of%20Credit%20Allocation.ipynb>`_
- `Interdisciplinarity <https://github.com/SciSciCollective/pyscisci/blob/master/examples/Method_Examples/Example%20of%20Interdisciplinarity.ipynb>`_
- `Novelty and Conventionality <https://github.com/SciSciCollective/pyscisci/blob/master/examples/Method_Examples/Example%20Novelty.ipynb>`_
- `Cocitation Network <https://github.com/SciSciCollective/pyscisci/blob/master/examples/Method_Examples/Example%20of%20cocitation%20network.ipynb>`_
- `Methods for Publication Impact <https://github.com/SciSciCollective/pyscisci/blob/master/examples/Method_Examples/Example%20Publication%20Citations.ipynb>`_
- `Career Analysis <https://github.com/SciSciCollective/pyscisci/blob/master/examples/Method_Examples/Career%20Analysis.ipynb>`_
- `Career Topic Switching <https://github.com/SciSciCollective/pyscisci/blob/master/examples/Method_Examples/Example%20Career%20Topic%20Switching.ipynb>`_
- `Field Reference Strength <https://github.com/SciSciCollective/pyscisci/blob/master/examples/Method_Examples/Example%20Reference%20Strength.ipynb>`_
- `Node2Vec Coauthorship <https://github.com/SciSciCollective/pyscisci/blob/master/examples/Method_Examples/Example_Node2vec%20(umap%2Csem_axis).ipynb>`_
- `CoWord Network <https://github.com/SciSciCollective/pyscisci/blob/master/examples/NLP_Examples/Example%20of%20Coword%20Mention%20Network.ipynb>`_

Advanced Functionality
-------------------------
- `Using Dask <https://github.com/SciSciCollective/pyscisci/blob/master/examples/Getting_Started/Getting%20Started%20with%20a%20Dask%20Example.ipynb>`_
- `Working from a publication List <https://github.com/SciSciCollective/pyscisci/blob/master/examples/Getting_Started/Working%20from%20a%20publication%20list.ipynb>`_

Science of Science Textbook
----------------------------
Examples taken from different chapters of the Science of Science Textbook :cite:`Wang2021scisci`.

- `Chapter 0 Data Prep <https://github.com/SciSciCollective/pyscisci/blob/master/examples/ScienceOfScienceTextbook/Chapter%200%20Preparing%20PySciSci.ipynb>`_
- `Chapter 1 Productivity of a Scientist <https://github.com/examples/SciSciCollective/pyscisci/blob/master/examples/ScienceOfScienceTextbook/Chapter%2001%20Productivity%20of%20a%20Scientist.ipynb>`_
- `Chapter 2 The HIndex <https://github.com/SciSciCollective/pyscisci/blob/master/examples/ScienceOfScienceTextbook/Chapter%2002%20The%20h-index.ipynb>`_
- `Chapter 5 The Random Impact Rule <https://github.com/SciSciCollective/pyscisci/blob/master/examples/ScienceOfScienceTextbook/Chapter%2005%20Random%20Impact%20Rule.ipynb>`_
- `Chapter 6 The Qfactor <https://github.com/SciSciCollective/pyscisci/blob/master/examples/ScienceOfScienceTextbook/Chapter%2006%20The%20Q-Factor.ipynb>`_
- `Chapter 14 Credit Allocation <https://github.com/SciSciCollective/pyscisci/blob/master/examples/ScienceOfScienceTextbook/Chapter%2014%20Credit%20Allocation.ipynb>`_
